@@ -49,11 +49,10 @@ __DATA__
 
 __compclass__
 package [% class %];
+use Moose;
+use namespace::autoclean;
 
-use strict;
-use warnings;
-
-use base 'Catalyst::View::TT';
+extends 'Catalyst::View::TT';
 
 __PACKAGE__->config(
     TEMPLATE_EXTENSION => '.tt',
